from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="WordImg",
    version="1.0.1",  # Updated version
    packages=find_packages(),
    include_package_data=True,
    install_requires=["Pillow"],
    package_data={"wordimg": ["fonts/font.ttf"]},  # Include font files
    author="Delta",
    description="A library to generate text images with custom backgrounds.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/geektyper",
    project_urls={
        "Website": "https://deltaop.tech",
        "GitHub": "https://github.com/geektyper",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)